aboutsummaryrefslogtreecommitdiffstats
path: root/repository/repo.go
diff options
context:
space:
mode:
Diffstat (limited to 'repository/repo.go')
-rw-r--r--repository/repo.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/repository/repo.go b/repository/repo.go
index e8c67a5e..71bd7a8e 100644
--- a/repository/repo.go
+++ b/repository/repo.go
@@ -111,13 +111,13 @@ type ClockedRepo interface {
// EditTimeIncrement increment the edit clock and return the new value.
EditTimeIncrement() (lamport.Time, error)
// CreateWitness witness another create time and increment the corresponding
// clock if needed.
- CreateWitness(time lamport.Time) error
+ WitnessCreate(time lamport.Time) error
- // EditWitness witness another edition time and increment the corresponding
+ // WitnessEdit witness another edition time and increment the corresponding
// clock if needed.
- EditWitness(time lamport.Time) error
+ WitnessEdit(time lamport.Time) error
}
// Witnesser is a function that will initialize the clocks of a repo
@@ -111,13 +111,13 @@ type ClockedRepo interface {
// EditTimeIncrement increment the edit clock and return the new value.
EditTimeIncrement() (lamport.Time, error)
- // CreateWitness witness another create time and increment the corresponding
+ // WitnessCreate witness another create time and increment the corresponding
// clock if needed.